@@ -15,6 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
-.onAttach <- function(libname, pkgname){
-	.Call( "initUncaughtExceptionHandler", PACKAGE = pkgname )
+.onLoad <- function(libname, pkgname){
+	.Call( "initRcpp", PACKAGE = pkgname )
 }
