@@ -323,4 +323,20 @@ test.environment.square <- function(){
 	
 }
 
+test.environment.Rcpp <- function(){
+	funx <- cfunction(signature(), '
+	return Environment::Rcpp_namespace() ;
+	', Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	checkEquals( funx(), asNamespace("Rcpp") , msg = "cached Rcpp namespace" )
+}
+
+test.environment.child <- function(){
+	funx <- cfunction(signature(), '
+	Environment global_env = Environment::global_env() ;
+	return global_env.new_child(false) ;
+	', Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	checkEquals( parent.env(funx()), globalenv(), 
+		msg = "" )
+}
+
 
