@@ -26,7 +26,8 @@ if( Rcpp:::capabilities()[["initializer lists"]] ){
 	test.wrap.initializerlist.int <- function(){
 		funx <- cfunction(signature(), '
 		return Rcpp::wrap( {0,1,2} ); 
-		', Rcpp=TRUE, verbose=FALSE)
+		', Rcpp=TRUE, verbose=FALSE,
+			cxxargs = "-std=c++0x")
 		checkEquals( funx(), 0:2, 
 			msg = "wrap( initializer_list<int> )" )
 	}
@@ -34,7 +35,8 @@ if( Rcpp:::capabilities()[["initializer lists"]] ){
 	test.wrap.initializerlist.double <- function(){
 		funx <- cfunction(signature(), '
 		return Rcpp::wrap( {0.0,1.0,2.0} ); 
-		', Rcpp=TRUE, verbose=FALSE)
+		', Rcpp=TRUE, verbose=FALSE,
+			cxxargs = "-std=c++0x")
 		checkEquals( funx(), as.numeric(0:2), 
 			msg = "wrap( initializer_list<double> )" )
 	}
@@ -42,7 +44,8 @@ if( Rcpp:::capabilities()[["initializer lists"]] ){
 	test.wrap.initializerlist.bool <- function(){
 		funx <- cfunction(signature(), '
 		return Rcpp::wrap( {false, true, false} ); 
-		', Rcpp=TRUE, verbose=FALSE)
+		', Rcpp=TRUE, verbose=FALSE,
+			cxxargs = "-std=c++0x")
 		checkEquals( funx(), c(FALSE, TRUE, FALSE), 
 			msg = "wrap( initializer_list<bool> )" )
 	}
@@ -50,7 +53,8 @@ if( Rcpp:::capabilities()[["initializer lists"]] ){
 	test.wrap.initializerlist.Rbyte <- function(){
 		funx <- cfunction(signature(), '
 		return Rcpp::wrap( { (Rbyte)0, (Rbyte)1 } ); 
-		', Rcpp=TRUE, verbose=FALSE)
+		', Rcpp=TRUE, verbose=FALSE,
+			cxxargs = "-std=c++0x")
 		checkEquals( funx(), as.raw(0:1), 
 			msg = "wrap( initializer_list<Rbyte> )" )
 	}
