@@ -41,12 +41,12 @@ public:
     		 */
     		no_such_binding( const std::string& binding) ;
     		
+    		virtual ~no_such_binding() throw() ;
+    		
     		/**
     		 * The message: no such binding : '{binding}' 
     		 */
-    		const char* what() const throw();
-    		
-    		~no_such_binding() throw() ;
+    		virtual const char* what() const throw();
     		
     	private:
     		std::string message ;
@@ -62,13 +62,13 @@ public:
     		 * @param binding name of the binding
     		 */
     		binding_is_locked( const std::string& binding) ;
-    		
+    		virtual ~binding_is_locked() throw() ;
+
     		/**
     		 * The message: binding is locked : '{binding}' 
     		 */
-    		const char* what() const throw() ;
-    		
-    		~binding_is_locked() throw() ;
+    		virtual const char* what() const throw() ;
+
     	private:
     		std::string message ;
     } ;
@@ -84,12 +84,14 @@ public:
     		 */
     		no_such_namespace( const std::string& package) ;
     		
+    		virtual ~no_such_namespace() throw() ;
+    		
     		/**
     		 * The message: no such namespace : '{package}' 
     		 */
-    		const char* what() const throw() ;
+    		virtual const char* what() const throw() ;
+    		
     		
-    		~no_such_namespace() throw() ;
     	private:
     		std::string message ;
     } ;
@@ -109,13 +111,14 @@ public:
     		 * @paral pos search path position where there is no environment
     		 */
     		no_such_env(int pos) ;
+    		virtual ~no_such_env() throw() ;
     		
     		/**
     		 * The message: no such environment : '{name}' 
     		 */
-    		const char* what() const throw() ;
+    		virtual const char* what() const throw() ;
+    		
     		
-    		~no_such_env() throw() ;
     	private:
     		std::string message ;
     } ;
@@ -223,6 +226,14 @@ public:
     	     */
     	    operator RObject() const ;
     	    
+    	    template <typename T> 
+    	    operator T() const{
+    	    	    SEXP x = env.get(name) ;
+    	    	    T t(x) ;
+    	    	    return t; 
+    	    }
+    	    
+    	    
     private:
     	    /**
     	     * Reference to the environment if the binding
@@ -413,6 +424,11 @@ public:
      */
     static Environment base_namespace() throw() ;
     
+    /**
+     * @return the Rcpp namespace
+     */
+    static Environment& Rcpp_namespace() throw() ;
+    
     /**
      * @param name the name of the package of which we want the namespace
      *
@@ -427,6 +443,15 @@ public:
      */
     Environment parent() const throw() ;
     
+    /**
+     * creates a new environment whose this is the parent
+     */
+    Environment new_child(bool hashed) ; 
+    
+private:
+	/* we cache the Rcpp namespace environment since
+	it is used many times internally */
+	static Environment RCPP_NAMESPACE ;
 };
 
 } // namespace Rcpp
